@@ -68,8 +68,7 @@ void processArgs(QCommandLineParser* parser, DiscoverObject* mainWindow)
         mainWindow->openMimeType(parser->value(QStringLiteral("mime")));
     else if(parser->isSet(QStringLiteral("category")))
         mainWindow->openCategory(parser->value(QStringLiteral("category")));
-
-    if(parser->isSet(QStringLiteral("mode")))
+    else if(parser->isSet(QStringLiteral("mode")))
         mainWindow->openMode(parser->value(QStringLiteral("mode")));
     else
         mainWindow->openMode(QStringLiteral("Browsing"));
@@ -97,9 +96,7 @@ int main(int argc, char** argv)
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("plasmadiscover")));
     app.setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 13, 0)
     app.setAttribute(Qt::AA_DisableSessionManager, true);
-#endif
     KCrash::initialize();
     KQuickAddons::QtQuickSettings::init();
     KLocalizedString::setApplicationDomain("plasma-discover");
